use futures::prelude::*;
use irc::client::prelude::*;

#[tokio::main]
async fn main() -> irc::error::Result<()> {
    let config = Config {
        nickname: Some("wumpscut".to_owned()),
        server: Some("ircd.chat".to_owned()),
        channels: vec!["#tcpdirect".to_owned()],
        port: Some(6697),
        use_tls: Some(true),
        ..Default::default()
    };

    let mut client = Client::from_config(config).await?;
    client.identify()?;

    let mut stream = client.stream()?;
    let sender = client.sender();

    while let Some(message) = stream.next().await.transpose()? {
        print!("{}", message);

        match message.command {
            Command::PRIVMSG(ref target, ref msg) => {
                if msg.contains(client.current_nickname()) {
                    sender.send_privmsg(target, "oi")?;
                }
            }
            _ => (),
        }
    }

    Ok(())
}
