use futures::prelude::*;
use irc::{client::prelude::*, error};
//use std::time::Duration;
    
#[tokio::main]
async fn main() -> irc::error::Result<()> {
    env_logger::init();

    let cfg1 = Config {
        nickname: Some("roobot".to_owned()),
        server: Some("ircd.chat".to_owned()),
        channels: vec!["#tcpdirect".to_owned()],
        port: Some(6697),
        use_tls: Some(true),
        ..Default::default()
    };

    let configs = vec![cfg1];
    let mut streams = Vec::new();
    let mut senders = Vec::new();

    for config in configs {
     
        let mut client = Client::from_config(config).await?;
        client.identify()?;

        streams.push(client.stream()?);
        senders.push(client.sender());
    }

    loop {
        let (message, index, _) =
            futures::future::select_all(streams.iter_mut().map(|s| s.select_next_some())).await;
        let message = message?;
        let sender = &senders[index];
        process_msg(sender, message)?;
    }

}

fn process_msg(sender: &Sender, message: Message) -> error::Result<()> {
    print!("{}", message);

    let bothelpcmds: [&str; 3] = ["?list","?join","?msg"];

    match message.command {
        Command::PRIVMSG(ref target, ref msg) => {
            //let string_list = vec!["?".to_string(), "roobot".to_string()];
            //let joined = string_list.join("");
            // test
            for bothelpcmd in &bothelpcmds
            {
                if msg.contains(bothelpcmd)
                {
                    let string_list = vec![bothelpcmd.to_string(), " command noticed".to_string()];
                    let ircmsg = string_list.join("");
                    sender.send_privmsg(target, ircmsg)?;
                    if bothelpcmd == &"?list"
                    {
                        sender.send_privmsg(target, "performing list operation")?;
                        sender.send_chanlist("","")?;
                    }
                }    
            }
        }
        Command::Response(Response::RPL_LISTSTART, _) => {
            sender.send_privmsg("#tcpdirect", "321 start of channel list")?;
        }
        Command::Response(Response::RPL_LIST, _) => {
            sender.send_privmsg("#tcpdirect", message)?;
        }
        Command::Response(Response::RPL_LISTEND, _) => {
            sender.send_privmsg("#tcpdirect", "323 end of channel list")?;
        }
        _ => (),
    }

    Ok(())
}
